Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1203)

Unified Diff: remoting/host/ipc_video_frame_capturer.h

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/ipc_desktop_environment_unittest.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/ipc_video_frame_capturer.h
diff --git a/remoting/host/ipc_video_frame_capturer.h b/remoting/host/ipc_video_frame_capturer.h
index fd2cdff3590a8277f8bb95604537c291522e08f2..396bdd5707a392a6d5733e64efc86449a15b6e27 100644
--- a/remoting/host/ipc_video_frame_capturer.h
+++ b/remoting/host/ipc_video_frame_capturer.h
@@ -8,19 +8,15 @@
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
#include "base/memory/scoped_ptr.h"
-#include "third_party/webrtc/modules/desktop_capture/screen_capturer.h"
-
-namespace media {
-struct MouseCursorShape;
-} // namespace media
+#include "third_party/webrtc/modules/desktop_capture/desktop_capturer.h"
namespace remoting {
class DesktopSessionProxy;
// Routes webrtc::ScreenCapturer calls though the IPC channel to the desktop
// session agent running in the desktop integration process.
-class IpcVideoFrameCapturer : public webrtc::ScreenCapturer {
+class IpcVideoFrameCapturer : public webrtc::DesktopCapturer {
public:
explicit IpcVideoFrameCapturer(
scoped_refptr<DesktopSessionProxy> desktop_session_proxy);
@@ -30,25 +26,12 @@ class IpcVideoFrameCapturer : public webrtc::ScreenCapturer {
virtual void Start(Callback* callback) OVERRIDE;
virtual void Capture(const webrtc::DesktopRegion& region) OVERRIDE;
- // webrtc::ScreenCapturer interface.
- virtual void SetMouseShapeObserver(
- MouseShapeObserver* mouse_shape_observer) OVERRIDE;
-
- virtual bool GetScreenList(ScreenList* screens) OVERRIDE;
-
- virtual bool SelectScreen(webrtc::ScreenId id) OVERRIDE;
-
// Called when a video |frame| has been captured.
void OnCaptureCompleted(scoped_ptr<webrtc::DesktopFrame> frame);
- // Called when the cursor shape has changed.
- void OnCursorShapeChanged(scoped_ptr<webrtc::MouseCursorShape> cursor_shape);
-
private:
- // Points to the callback passed to webrtc::ScreenCapturer::Start().
- webrtc::ScreenCapturer::Callback* callback_;
-
- MouseShapeObserver* mouse_shape_observer_;
+ // Points to the callback passed to webrtc::DesktopCapturer::Start().
+ webrtc::DesktopCapturer::Callback* callback_;
// Wraps the IPC channel to the desktop session agent.
scoped_refptr<DesktopSessionProxy> desktop_session_proxy_;
« no previous file with comments | « remoting/host/ipc_desktop_environment_unittest.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »
@@ -8,19 +8,15 @@
namespace remoting {
class DesktopSessionProxy;
-// Routes webrtc::ScreenCapturer calls though the IPC channel to the desktop
+// Routes webrtc::DesktopCapturer calls though the IPC channel to the desktop
// session agent running in the desktop integration process.

Powered by Google App Engine
This is Rietveld 408576698